* [PATCH v4 0/4] Add support for gdsp remoteproc on sa8775p
@ 2025-06-27 10:33 Ling Xu
2025-06-27 10:33 ` [PATCH v4 1/4] dt-bindings: misc: qcom,fastrpc: Add GDSP label Ling Xu
` (3 more replies)
0 siblings, 4 replies; 10+ messages in thread
From: Ling Xu @ 2025-06-27 10:33 UTC (permalink / raw)
To: srini, amahesh, robh, krzk+dt, conor+dt, andersson, konradybcio,
arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel, Ling Xu
The fastrpc driver has support for 5 types of remoteprocs. There are
some products which support GDSP remoteprocs. GDSP is General Purpose
DSP where tasks can be offloaded. Add fastrpc nodes and task offload
support for GDSP. Also strict domain IDs for domain.
Patch [v3]: https://lore.kernel.org/linux-arm-msm/20250622133820.18369-1-quic_lxu5@quicinc.com/
Changes in v4:
- Split patch and change to common syntax.
Changes in v3:
- Restrict domain IDs to represent a domain.
Changes in v2:
- Add GPDSP labels in dt-bindings.
Ling Xu (4):
dt-bindings: misc: qcom,fastrpc: Add GDSP label
arm64: dts: qcom: sa8775p: add GDSP fastrpc-compute-cb nodes
misc: fastrpc: Refactor domain ID to enforce strict mapping
misc: fastrpc: add support for gdsp remoteproc
.../bindings/misc/qcom,fastrpc.yaml | 2 +
arch/arm64/boot/dts/qcom/sa8775p.dtsi | 57 +++++++++++++++++++
drivers/misc/fastrpc.c | 57 ++++++++-----------
include/uapi/misc/fastrpc.h | 8 +++
4 files changed, 91 insertions(+), 33 deletions(-)
--
2.34.1
^ permalink raw reply [flat|nested] 10+ messages in thread
* [PATCH v4 1/4] dt-bindings: misc: qcom,fastrpc: Add GDSP label
2025-06-27 10:33 [PATCH v4 0/4] Add support for gdsp remoteproc on sa8775p Ling Xu
@ 2025-06-27 10:33 ` Ling Xu
2025-06-28 12:36 ` Krzysztof Kozlowski
2025-06-27 10:33 ` [PATCH v4 2/4] arm64: dts: qcom: sa8775p: add GDSP fastrpc-compute-cb nodes Ling Xu
` (2 subsequent siblings)
3 siblings, 1 reply; 10+ messages in thread
From: Ling Xu @ 2025-06-27 10:33 UTC (permalink / raw)
To: srini, amahesh, robh, krzk+dt, conor+dt, andersson, konradybcio,
arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel, Ling Xu
Add "gdsp" as the new supported label for GDSP fastrpc domain.
Signed-off-by: Ling Xu <quic_lxu5@quicinc.com>
---
Documentation/devicetree/bindings/misc/qcom,fastrpc.yaml | 2 ++
1 file changed, 2 insertions(+)
diff --git a/Documentation/devicetree/bindings/misc/qcom,fastrpc.yaml b/Documentation/devicetree/bindings/misc/qcom,fastrpc.yaml
index 0840a3d92513..3f6199fc9ae6 100644
--- a/Documentation/devicetree/bindings/misc/qcom,fastrpc.yaml
+++ b/Documentation/devicetree/bindings/misc/qcom,fastrpc.yaml
@@ -27,6 +27,8 @@ properties:
- sdsp
- cdsp
- cdsp1
+ - gdsp0
+ - gdsp1
memory-region:
maxItems: 1
--
2.34.1
^ permalink raw reply related [flat|nested] 10+ messages in thread
* [PATCH v4 2/4] arm64: dts: qcom: sa8775p: add GDSP fastrpc-compute-cb nodes
2025-06-27 10:33 [PATCH v4 0/4] Add support for gdsp remoteproc on sa8775p Ling Xu
2025-06-27 10:33 ` [PATCH v4 1/4] dt-bindings: misc: qcom,fastrpc: Add GDSP label Ling Xu
@ 2025-06-27 10:33 ` Ling Xu
2025-06-27 12:17 ` Konrad Dybcio
2025-06-27 10:33 ` [PATCH v4 3/4] misc: fastrpc: Refactor domain ID to enforce strict mapping Ling Xu
2025-06-27 10:33 ` [PATCH v4 4/4] misc: fastrpc: add support for gdsp remoteproc Ling Xu
3 siblings, 1 reply; 10+ messages in thread
From: Ling Xu @ 2025-06-27 10:33 UTC (permalink / raw)
To: srini, amahesh, robh, krzk+dt, conor+dt, andersson, konradybcio,
arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel, Ling Xu, Dmitry Baryshkov
Add GDSP0 and GDSP1 fastrpc compute-cb nodes for sa8775p SoC.
Reviewed-by: Dmitry Baryshkov <dmitry.baryshkov@oss.qualcomm.com>
Signed-off-by: Ling Xu <quic_lxu5@quicinc.com>
---
arch/arm64/boot/dts/qcom/sa8775p.dtsi | 57 +++++++++++++++++++++++++++
1 file changed, 57 insertions(+)
diff --git a/arch/arm64/boot/dts/qcom/sa8775p.dtsi b/arch/arm64/boot/dts/qcom/sa8775p.dtsi
index 45f536633f64..f69fb1d05a0d 100644
--- a/arch/arm64/boot/dts/qcom/sa8775p.dtsi
+++ b/arch/arm64/boot/dts/qcom/sa8775p.dtsi
@@ -5605,6 +5605,34 @@ IPCC_MPROC_SIGNAL_GLINK_QMP
label = "gpdsp0";
qcom,remote-pid = <17>;
+
+ fastrpc {
+ compatible = "qcom,fastrpc";
+ qcom,glink-channels = "fastrpcglink-apps-dsp";
+ label = "gdsp0";
+ #address-cells = <1>;
+ #size-cells = <0>;
+
+ compute-cb@1 {
+ compatible = "qcom,fastrpc-compute-cb";
+ reg = <1>;
+ iommus = <&apps_smmu 0x38a1 0x0>;
+ dma-coherent;
+ };
+
+ compute-cb@2 {
+ compatible = "qcom,fastrpc-compute-cb";
+ reg = <2>;
+ iommus = <&apps_smmu 0x38a2 0x0>;
+ dma-coherent;
+ };
+ compute-cb@3 {
+ compatible = "qcom,fastrpc-compute-cb";
+ reg = <3>;
+ iommus = <&apps_smmu 0x38a3 0x0>;
+ dma-coherent;
+ };
+ };
};
};
@@ -5648,6 +5676,35 @@ IPCC_MPROC_SIGNAL_GLINK_QMP
label = "gpdsp1";
qcom,remote-pid = <18>;
+
+ fastrpc {
+ compatible = "qcom,fastrpc";
+ qcom,glink-channels = "fastrpcglink-apps-dsp";
+ label = "gdsp1";
+ #address-cells = <1>;
+ #size-cells = <0>;
+
+ compute-cb@1 {
+ compatible = "qcom,fastrpc-compute-cb";
+ reg = <1>;
+ iommus = <&apps_smmu 0x38c1 0x0>;
+ dma-coherent;
+ };
+
+ compute-cb@2 {
+ compatible = "qcom,fastrpc-compute-cb";
+ reg = <2>;
+ iommus = <&apps_smmu 0x38c2 0x0>;
+ dma-coherent;
+ };
+
+ compute-cb@3 {
+ compatible = "qcom,fastrpc-compute-cb";
+ reg = <3>;
+ iommus = <&apps_smmu 0x38c3 0x0>;
+ dma-coherent;
+ };
+ };
};
};
--
2.34.1
^ permalink raw reply related [flat|nested] 10+ messages in thread
* [PATCH v4 3/4] misc: fastrpc: Refactor domain ID to enforce strict mapping
2025-06-27 10:33 [PATCH v4 0/4] Add support for gdsp remoteproc on sa8775p Ling Xu
2025-06-27 10:33 ` [PATCH v4 1/4] dt-bindings: misc: qcom,fastrpc: Add GDSP label Ling Xu
2025-06-27 10:33 ` [PATCH v4 2/4] arm64: dts: qcom: sa8775p: add GDSP fastrpc-compute-cb nodes Ling Xu
@ 2025-06-27 10:33 ` Ling Xu
2025-06-27 12:23 ` Konrad Dybcio
2025-06-27 10:33 ` [PATCH v4 4/4] misc: fastrpc: add support for gdsp remoteproc Ling Xu
3 siblings, 1 reply; 10+ messages in thread
From: Ling Xu @ 2025-06-27 10:33 UTC (permalink / raw)
To: srini, amahesh, robh, krzk+dt, conor+dt, andersson, konradybcio,
arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel, Ling Xu, Srinivas Kandagatla
Currently, domain ids are added for each instance, which is not a scalable.
Strict domain IDs for domain.
Co-developed-by: Srinivas Kandagatla <srinivas.kandagatla@linaro.org>
Signed-off-by: Srinivas Kandagatla <srinivas.kandagatla@linaro.org>
Signed-off-by: Ling Xu <quic_lxu5@quicinc.com>
---
drivers/misc/fastrpc.c | 54 +++++++++++++++----------------------
include/uapi/misc/fastrpc.h | 7 +++++
2 files changed, 28 insertions(+), 33 deletions(-)
diff --git a/drivers/misc/fastrpc.c b/drivers/misc/fastrpc.c
index 378923594f02..cb9f4be286af 100644
--- a/drivers/misc/fastrpc.c
+++ b/drivers/misc/fastrpc.c
@@ -23,12 +23,6 @@
#include <uapi/misc/fastrpc.h>
#include <linux/of_reserved_mem.h>
-#define ADSP_DOMAIN_ID (0)
-#define MDSP_DOMAIN_ID (1)
-#define SDSP_DOMAIN_ID (2)
-#define CDSP_DOMAIN_ID (3)
-#define CDSP1_DOMAIN_ID (4)
-#define FASTRPC_DEV_MAX 5 /* adsp, mdsp, slpi, cdsp, cdsp1 */
#define FASTRPC_MAX_SESSIONS 14
#define FASTRPC_MAX_VMIDS 16
#define FASTRPC_ALIGN 128
@@ -106,8 +100,6 @@
#define miscdev_to_fdevice(d) container_of(d, struct fastrpc_device, miscdev)
-static const char *domains[FASTRPC_DEV_MAX] = { "adsp", "mdsp",
- "sdsp", "cdsp", "cdsp1" };
struct fastrpc_phy_page {
u64 addr; /* physical address */
u64 size; /* size of contiguous region */
@@ -1723,7 +1715,6 @@ static int fastrpc_get_info_from_kernel(struct fastrpc_ioctl_capability *cap,
uint32_t attribute_id = cap->attribute_id;
uint32_t *dsp_attributes;
unsigned long flags;
- uint32_t domain = cap->domain;
int err;
spin_lock_irqsave(&cctx->lock, flags);
@@ -1741,7 +1732,7 @@ static int fastrpc_get_info_from_kernel(struct fastrpc_ioctl_capability *cap,
err = fastrpc_get_info_from_dsp(fl, dsp_attributes, FASTRPC_MAX_DSP_ATTRIBUTES);
if (err == DSP_UNSUPPORTED_API) {
dev_info(&cctx->rpdev->dev,
- "Warning: DSP capabilities not supported on domain: %d\n", domain);
+ "Warning: DSP capabilities not supported\n");
kfree(dsp_attributes);
return -EOPNOTSUPP;
} else if (err) {
@@ -1769,17 +1760,6 @@ static int fastrpc_get_dsp_info(struct fastrpc_user *fl, char __user *argp)
return -EFAULT;
cap.capability = 0;
- if (cap.domain >= FASTRPC_DEV_MAX) {
- dev_err(&fl->cctx->rpdev->dev, "Error: Invalid domain id:%d, err:%d\n",
- cap.domain, err);
- return -ECHRNG;
- }
-
- /* Fastrpc Capablities does not support modem domain */
- if (cap.domain == MDSP_DOMAIN_ID) {
- dev_err(&fl->cctx->rpdev->dev, "Error: modem not supported %d\n", err);
- return -ECHRNG;
- }
if (cap.attribute_id >= FASTRPC_MAX_DSP_ATTRIBUTES) {
dev_err(&fl->cctx->rpdev->dev, "Error: invalid attribute: %d, err: %d\n",
@@ -2255,6 +2235,20 @@ static int fastrpc_device_register(struct device *dev, struct fastrpc_channel_ct
return err;
}
+static int fastrpc_get_domain_id(const char *domain)
+{
+ if (!strncmp(domain, "adsp", 4))
+ return ADSP_DOMAIN_ID;
+ else if (!strncmp(domain, "cdsp", 4))
+ return CDSP_DOMAIN_ID;
+ else if (!strncmp(domain, "mdsp", 4))
+ return MDSP_DOMAIN_ID;
+ else if (!strncmp(domain, "sdsp", 4))
+ return SDSP_DOMAIN_ID;
+
+ return -EINVAL;
+}
+
static int fastrpc_rpmsg_probe(struct rpmsg_device *rpdev)
{
struct device *rdev = &rpdev->dev;
@@ -2272,15 +2266,10 @@ static int fastrpc_rpmsg_probe(struct rpmsg_device *rpdev)
return err;
}
- for (i = 0; i < FASTRPC_DEV_MAX; i++) {
- if (!strcmp(domains[i], domain)) {
- domain_id = i;
- break;
- }
- }
+ domain_id = fastrpc_get_domain_id(domain);
if (domain_id < 0) {
- dev_info(rdev, "FastRPC Invalid Domain ID %d\n", domain_id);
+ dev_info(rdev, "FastRPC Domain %s not supported\n", domain);
return -EINVAL;
}
@@ -2330,21 +2319,20 @@ static int fastrpc_rpmsg_probe(struct rpmsg_device *rpdev)
case ADSP_DOMAIN_ID:
case MDSP_DOMAIN_ID:
case SDSP_DOMAIN_ID:
- /* Unsigned PD offloading is only supported on CDSP and CDSP1 */
+ /* Unsigned PD offloading is only supported on CDSP*/
data->unsigned_support = false;
- err = fastrpc_device_register(rdev, data, secure_dsp, domains[domain_id]);
+ err = fastrpc_device_register(rdev, data, secure_dsp, domain);
if (err)
goto err_free_data;
break;
case CDSP_DOMAIN_ID:
- case CDSP1_DOMAIN_ID:
data->unsigned_support = true;
/* Create both device nodes so that we can allow both Signed and Unsigned PD */
- err = fastrpc_device_register(rdev, data, true, domains[domain_id]);
+ err = fastrpc_device_register(rdev, data, true, domain);
if (err)
goto err_free_data;
- err = fastrpc_device_register(rdev, data, false, domains[domain_id]);
+ err = fastrpc_device_register(rdev, data, false, domain);
if (err)
goto err_deregister_fdev;
break;
diff --git a/include/uapi/misc/fastrpc.h b/include/uapi/misc/fastrpc.h
index f33d914d8f46..b890f8042e86 100644
--- a/include/uapi/misc/fastrpc.h
+++ b/include/uapi/misc/fastrpc.h
@@ -18,6 +18,13 @@
#define FASTRPC_IOCTL_MEM_UNMAP _IOWR('R', 11, struct fastrpc_mem_unmap)
#define FASTRPC_IOCTL_GET_DSP_INFO _IOWR('R', 13, struct fastrpc_ioctl_capability)
+#define ADSP_DOMAIN_ID (0)
+#define MDSP_DOMAIN_ID (1)
+#define SDSP_DOMAIN_ID (2)
+#define CDSP_DOMAIN_ID (3)
+
+#define FASTRPC_DOMAIN_MAX 3
+
/**
* enum fastrpc_map_flags - control flags for mapping memory on DSP user process
* @FASTRPC_MAP_STATIC: Map memory pages with RW- permission and CACHE WRITEBACK.
diff --git a/include/uapi/misc/fastrpc.h b/include/uapi/misc/fastrpc.h
index b890f8042e86..5ea891615c49 100644
--- a/include/uapi/misc/fastrpc.h
+++ b/include/uapi/misc/fastrpc.h
@@ -22,8 +22,9 @@
#define MDSP_DOMAIN_ID (1)
#define SDSP_DOMAIN_ID (2)
#define CDSP_DOMAIN_ID (3)
+#define GDSP_DOMAIN_ID (4)
-#define FASTRPC_DOMAIN_MAX 3
+#define FASTRPC_DOMAIN_MAX 4
/**
* enum fastrpc_map_flags - control flags for mapping memory on DSP user process
--
2.34.1
^ permalink raw reply related [flat|nested] 10+ messages in thread
* [PATCH v4 4/4] misc: fastrpc: add support for gdsp remoteproc
2025-06-27 10:33 [PATCH v4 0/4] Add support for gdsp remoteproc on sa8775p Ling Xu
` (2 preceding siblings ...)
2025-06-27 10:33 ` [PATCH v4 3/4] misc: fastrpc: Refactor domain ID to enforce strict mapping Ling Xu
@ 2025-06-27 10:33 ` Ling Xu
2025-06-27 12:24 ` Konrad Dybcio
3 siblings, 1 reply; 10+ messages in thread
From: Ling Xu @ 2025-06-27 10:33 UTC (permalink / raw)
To: srini, amahesh, robh, krzk+dt, conor+dt, andersson, konradybcio,
arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel, Ling Xu
The fastrpc driver has support for 5 types of remoteprocs. There are
some products which support GDSP remoteprocs. GDSP is General Purpose
DSP where tasks can be offloaded. This patch extends the driver to
support GDSP remoteprocs.
Signed-off-by: Ling Xu <quic_lxu5@quicinc.com>
---
drivers/misc/fastrpc.c | 5 ++++-
include/uapi/misc/fastrpc.h | 3 ++-
2 files changed, 6 insertions(+), 2 deletions(-)
diff --git a/drivers/misc/fastrpc.c b/drivers/misc/fastrpc.c
index cb9f4be286af..d3d9b9fdbf4c 100644
--- a/drivers/misc/fastrpc.c
+++ b/drivers/misc/fastrpc.c
@@ -2245,6 +2245,8 @@ static int fastrpc_get_domain_id(const char *domain)
return MDSP_DOMAIN_ID;
else if (!strncmp(domain, "sdsp", 4))
return SDSP_DOMAIN_ID;
+ else if (!strncmp(domain, "gdsp", 4))
+ return GDSP_DOMAIN_ID;
return -EINVAL;
}
@@ -2319,13 +2321,14 @@ static int fastrpc_rpmsg_probe(struct rpmsg_device *rpdev)
case ADSP_DOMAIN_ID:
case MDSP_DOMAIN_ID:
case SDSP_DOMAIN_ID:
/* Unsigned PD offloading is only supported on CDSP*/
data->unsigned_support = false;
err = fastrpc_device_register(rdev, data, secure_dsp, domain);
if (err)
goto err_free_data;
break;
case CDSP_DOMAIN_ID:
+ case GDSP_DOMAIN_ID:
data->unsigned_support = true;
/* Create both device nodes so that we can allow both Signed and Unsigned PD */
err = fastrpc_device_register(rdev, data, true, domain);
@@ -2319,13 +2321,14 @@ static int fastrpc_rpmsg_probe(struct rpmsg_device *rpdev)
case MDSP_DOMAIN_ID:
case SDSP_DOMAIN_ID:
- /* Unsigned PD offloading is only supported on CDSP*/
+ /* Unsigned PD offloading is only supported on CDSP and GDSP*/
data->unsigned_support = false;
err = fastrpc_device_register(rdev, data, secure_dsp, domain);
--
2.34.1
^ permalink raw reply related [flat|nested] 10+ messages in thread
* Re: [PATCH v4 2/4] arm64: dts: qcom: sa8775p: add GDSP fastrpc-compute-cb nodes
2025-06-27 10:33 ` [PATCH v4 2/4] arm64: dts: qcom: sa8775p: add GDSP fastrpc-compute-cb nodes Ling Xu
@ 2025-06-27 12:17 ` Konrad Dybcio
0 siblings, 0 replies; 10+ messages in thread
From: Konrad Dybcio @ 2025-06-27 12:17 UTC (permalink / raw)
To: Ling Xu, srini, amahesh, robh, krzk+dt, conor+dt, andersson,
konradybcio, arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel, Dmitry Baryshkov
On 6/27/25 12:33 PM, Ling Xu wrote:
> Add GDSP0 and GDSP1 fastrpc compute-cb nodes for sa8775p SoC.
>
> Reviewed-by: Dmitry Baryshkov <dmitry.baryshkov@oss.qualcomm.com>
> Signed-off-by: Ling Xu <quic_lxu5@quicinc.com>
> ---
Reviewed-by: Konrad Dybcio <konrad.dybcio@oss.qualcomm.com>
Konrad
^ permalink raw reply [flat|nested] 10+ messages in thread
* Re: [PATCH v4 3/4] misc: fastrpc: Refactor domain ID to enforce strict mapping
2025-06-27 10:33 ` [PATCH v4 3/4] misc: fastrpc: Refactor domain ID to enforce strict mapping Ling Xu
@ 2025-06-27 12:23 ` Konrad Dybcio
2025-06-27 13:01 ` Srinivas Kandagatla
0 siblings, 1 reply; 10+ messages in thread
From: Konrad Dybcio @ 2025-06-27 12:23 UTC (permalink / raw)
To: Ling Xu, srini, amahesh, robh, krzk+dt, conor+dt, andersson,
konradybcio, arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel, Srinivas Kandagatla
On 6/27/25 12:33 PM, Ling Xu wrote:
> Currently, domain ids are added for each instance, which is not a scalable.
's/ a//g'
[...]
> - /* Unsigned PD offloading is only supported on CDSP and CDSP1 */
> + /* Unsigned PD offloading is only supported on CDSP*/
missing space before comment end
[...]
> index f33d914d8f46..b890f8042e86 100644
> --- a/include/uapi/misc/fastrpc.h
> +++ b/include/uapi/misc/fastrpc.h
> @@ -18,6 +18,13 @@
> #define FASTRPC_IOCTL_MEM_UNMAP _IOWR('R', 11, struct fastrpc_mem_unmap)
> #define FASTRPC_IOCTL_GET_DSP_INFO _IOWR('R', 13, struct fastrpc_ioctl_capability)
>
> +#define ADSP_DOMAIN_ID (0)
> +#define MDSP_DOMAIN_ID (1)
> +#define SDSP_DOMAIN_ID (2)
> +#define CDSP_DOMAIN_ID (3)
No need to include parentheses, as you're not interacting with any
variables
> +#define FASTRPC_DOMAIN_MAX 3
#define FASTRPC_DOMAIN_MAX CDSP_DOMAIN_ID?
What I meant in the previous revision is that you can not move
data inside the fastrpc_ioctl_capability struct, but you can
definitely add a comment like:
struct fastrpc_ioctl_capability {
__u32 domain; /* Retired in v6.whatever, now ignored by the kernel */
__u32 attribute_id;
__u32 capability; /* dsp capability */
__u32 reserved[4];
};
Konrad
^ permalink raw reply [flat|nested] 10+ messages in thread
* Re: [PATCH v4 4/4] misc: fastrpc: add support for gdsp remoteproc
2025-06-27 10:33 ` [PATCH v4 4/4] misc: fastrpc: add support for gdsp remoteproc Ling Xu
@ 2025-06-27 12:24 ` Konrad Dybcio
0 siblings, 0 replies; 10+ messages in thread
From: Konrad Dybcio @ 2025-06-27 12:24 UTC (permalink / raw)
To: Ling Xu, srini, amahesh, robh, krzk+dt, conor+dt, andersson,
konradybcio, arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel
On 6/27/25 12:33 PM, Ling Xu wrote:
> The fastrpc driver has support for 5 types of remoteprocs. There are
> some products which support GDSP remoteprocs. GDSP is General Purpose
> DSP where tasks can be offloaded. This patch extends the driver to
> support GDSP remoteprocs.
>
> Signed-off-by: Ling Xu <quic_lxu5@quicinc.com>
> ---
> drivers/misc/fastrpc.c | 5 ++++-
> include/uapi/misc/fastrpc.h | 3 ++-
> 2 files changed, 6 insertions(+), 2 deletions(-)
>
> diff --git a/drivers/misc/fastrpc.c b/drivers/misc/fastrpc.c
> index cb9f4be286af..d3d9b9fdbf4c 100644
> --- a/drivers/misc/fastrpc.c
> +++ b/drivers/misc/fastrpc.c
> @@ -2245,6 +2245,8 @@ static int fastrpc_get_domain_id(const char *domain)
> return MDSP_DOMAIN_ID;
> else if (!strncmp(domain, "sdsp", 4))
> return SDSP_DOMAIN_ID;
> + else if (!strncmp(domain, "gdsp", 4))
> + return GDSP_DOMAIN_ID;
>
> return -EINVAL;
> }
> @@ -2319,13 +2321,14 @@ static int fastrpc_rpmsg_probe(struct rpmsg_device *rpdev)
> case ADSP_DOMAIN_ID:
> case MDSP_DOMAIN_ID:
> case SDSP_DOMAIN_ID:
> - /* Unsigned PD offloading is only supported on CDSP*/
> + /* Unsigned PD offloading is only supported on CDSP and GDSP*/
missing space ^
Konrad
^ permalink raw reply [flat|nested] 10+ messages in thread
* Re: [PATCH v4 3/4] misc: fastrpc: Refactor domain ID to enforce strict mapping
2025-06-27 12:23 ` Konrad Dybcio
@ 2025-06-27 13:01 ` Srinivas Kandagatla
0 siblings, 0 replies; 10+ messages in thread
From: Srinivas Kandagatla @ 2025-06-27 13:01 UTC (permalink / raw)
To: Konrad Dybcio, Ling Xu, srini, amahesh, robh, krzk+dt, conor+dt,
andersson, konradybcio, arnd, gregkh
Cc: quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm, dri-devel,
linux-kernel, Srinivas Kandagatla
On 6/27/25 1:23 PM, Konrad Dybcio wrote:
> On 6/27/25 12:33 PM, Ling Xu wrote:
>> Currently, domain ids are added for each instance, which is not a scalable.
>
> 's/ a//g'
>
> [...]
>
>> - /* Unsigned PD offloading is only supported on CDSP and CDSP1 */
>> + /* Unsigned PD offloading is only supported on CDSP*/
>
> missing space before comment end
>
> [...]
>
>> index f33d914d8f46..b890f8042e86 100644
>> --- a/include/uapi/misc/fastrpc.h
>> +++ b/include/uapi/misc/fastrpc.h
>> @@ -18,6 +18,13 @@
>> #define FASTRPC_IOCTL_MEM_UNMAP _IOWR('R', 11, struct fastrpc_mem_unmap)
>> #define FASTRPC_IOCTL_GET_DSP_INFO _IOWR('R', 13, struct fastrpc_ioctl_capability)
>>
>> +#define ADSP_DOMAIN_ID (0)
>> +#define MDSP_DOMAIN_ID (1)
>> +#define SDSP_DOMAIN_ID (2)
>> +#define CDSP_DOMAIN_ID (3)
>
Pl move the defines back to driver, see below comments.
> No need to include parentheses, as you're not interacting with any
> variables
>
>> +#define FASTRPC_DOMAIN_MAX 3
>
> #define FASTRPC_DOMAIN_MAX CDSP_DOMAIN_ID?
>
> What I meant in the previous revision is that you can not move
> data inside the fastrpc_ioctl_capability struct, but you can
> definitely add a comment like:
>
> struct fastrpc_ioctl_capability {
> __u32 domain; /* Retired in v6.whatever, now ignored by the kernel */
hmm, If the plan is to make this field deprecated then why are we adding
the defines to UAPI, it does not make sense.
Also like Konrad suggested
> __u32 domain; /* deprecated, ignored by the kernel */
Also please move this change as a new patch incase you plan to add the
deprecation along with checks in the kernel to make sure no one is
actually passing data in this member.
--srini
> __u32 attribute_id;
> __u32 capability; /* dsp capability */
> __u32 reserved[4];
> };
>
> Konrad
^ permalink raw reply [flat|nested] 10+ messages in thread
* Re: [PATCH v4 1/4] dt-bindings: misc: qcom,fastrpc: Add GDSP label
2025-06-27 10:33 ` [PATCH v4 1/4] dt-bindings: misc: qcom,fastrpc: Add GDSP label Ling Xu
@ 2025-06-28 12:36 ` Krzysztof Kozlowski
0 siblings, 0 replies; 10+ messages in thread
From: Krzysztof Kozlowski @ 2025-06-28 12:36 UTC (permalink / raw)
To: Ling Xu
Cc: srini, amahesh, robh, krzk+dt, conor+dt, andersson, konradybcio,
arnd, gregkh, quic_kuiw, ekansh.gupta, devicetree, linux-arm-msm,
dri-devel, linux-kernel
On Fri, Jun 27, 2025 at 04:03:16PM +0530, Ling Xu wrote:
> Add "gdsp" as the new supported label for GDSP fastrpc domain.
>
> Signed-off-by: Ling Xu <quic_lxu5@quicinc.com>
> ---
> Documentation/devicetree/bindings/misc/qcom,fastrpc.yaml | 2 ++
> 1 file changed, 2 insertions(+)
>
NAK, nothing improved. You got comment and you just sent the same.
Best regards,
Krzysztof
^ permalink raw reply [flat|nested] 10+ messages in thread
end of thread, other threads:[~2025-06-28 12:36 UTC | newest]
Thread overview: 10+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2025-06-27 10:33 [PATCH v4 0/4] Add support for gdsp remoteproc on sa8775p Ling Xu
2025-06-27 10:33 ` [PATCH v4 1/4] dt-bindings: misc: qcom,fastrpc: Add GDSP label Ling Xu
2025-06-28 12:36 ` Krzysztof Kozlowski
2025-06-27 10:33 ` [PATCH v4 2/4] arm64: dts: qcom: sa8775p: add GDSP fastrpc-compute-cb nodes Ling Xu
2025-06-27 12:17 ` Konrad Dybcio
2025-06-27 10:33 ` [PATCH v4 3/4] misc: fastrpc: Refactor domain ID to enforce strict mapping Ling Xu
2025-06-27 12:23 ` Konrad Dybcio
2025-06-27 13:01 ` Srinivas Kandagatla
2025-06-27 10:33 ` [PATCH v4 4/4] misc: fastrpc: add support for gdsp remoteproc Ling Xu
2025-06-27 12:24 ` Konrad Dybcio
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox